==> theia-0.1.8.11-py3-none-any.whl: theia/aws/serverless/lambda_.py <==
import pulumi

from pulumi_aws import lambda_
from pulumi.output import Output

from dataclasses import field
from typing import Optional, Literal, List, Mapping
from pydantic.dataclasses import dataclass, ConfigDict

from theia import ResourceOptions
from theia._registry import StackRegistry, GlobalTags
from theia.utils.errors import TheiaConfigurationError
from theia.definitions import THEIA_VERSION, LAMBDA_RUNTIMES


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class VpcConfig:
    security_group_ids: List[str | Output[str]]
    subnet_ids: List[str | Output[str]]
    vpc_id: Optional[str | Output[str]] = None


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class FunctionSettings:
    architectures: List[Optional[Literal["x86_64", "arm64"]]] = field(
        default_factory=lambda: ["x86_64"]
    )
    description: Optional[str] = None
    env_args: Optional[Mapping[str, str | Output[str]]] = None
    memory_size: Optional[int] = 128
    timeout: Optional[int] = 3
    alias_name: Optional[str] = None
    image_uri: Optional[str | Output[str]] = None
    s3_bucket: Optional[str | Output[str]] = None
    s3_key: Optional[str | Output[str]] = None
    s3_object_version: Optional[str | Output[str]] = None
    vpc_config: Optional[VpcConfig] = None
    api_permissions: Optional[List[str | Output[str]]] = None


    def __post_init__(self):
        if self.s3_bucket and not self.s3_key:
            raise TheiaConfigurationError(
                "s3 bucket was configured as source but s3 key was not provided"
            )


class Function:
    def __new__(
        cls,
        resource_name: str,
        role_arn: str,
        runtime: LAMBDA_RUNTIMES,
        code_path: Optional[str] = None,
        publish: Optional[bool] = False,
        handler: Optional[str] = False,
        settings: Optional[FunctionSettings] = FunctionSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> lambda_.Function:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        if not code_path and not (settings.image_uri or settings.s3_bucket):
            raise TheiaConfigurationError(
                "Exactly one of code_path, FunctionSettings(image_uri) or FunctionSettings(s3_bucket) must be provided"
            )
        if settings.image_uri:
            package_type = "Image"
        else:
            package_type = "Zip"

        function_args = lambda_.FunctionArgs(
            role=role_arn,
            architectures=settings.architectures,
            code=pulumi.FileArchive(code_path),
            description=settings.description,
            environment=lambda_.FunctionEnvironmentArgs(variables=settings.env_args),
            package_type=package_type,
            handler=handler,
            image_uri=settings.image_uri,
            s3_bucket=settings.s3_bucket,
            s3_key=settings.s3_key,
            s3_object_version=settings.s3_object_version,
            runtime=runtime,
            publish=publish,
            memory_size=settings.memory_size,
            timeout=settings.timeout,
            vpc_config=lambda_.FunctionVpcConfigArgs(
                security_group_ids=settings.vpc_config.security_group_ids,
                subnet_ids=settings.vpc_config.subnet_ids,
                vpc_id=settings.vpc_config.vpc_id,
            ),
            tags=merged_tags,
        )

        function = lambda_.Function(
            resource_name, name=resource_name, args=function_args, opts=opts
        )
        
        if settings.alias_name:
            lambda_.Alias(
                resource_name=settings.alias_name,
                function_version=1,
                function_name=function.arn
            )

        if settings.api_permissions:
            for api_execution_arn in settings.api_permissions:
                lambda_.Permission("lambdaPermission",
                    action="lambda:InvokeFunction",
                    function=function,
                    principal="apigateway.amazonaws.com",
                    source_arn=api_execution_arn
                )

        pulumi.export(
            f"lambda---{resource_name}",
            {
                "id": function.id,
                "arn": function.arn,
                "invoke_arn": function.invoke_arn,
            },
        )

        return function

    @staticmethod
    def import_(stack: str, resource_name: str) -> lambda_.Function:
        stack_ref = StackRegistry.get(stack_name=stack)
        func = stack_ref.get_output(name=f"lambda---{resource_name}")
        return lambda_.Function.get(resource_name=resource_name, id=func["id"])

==> theia-0.1.8.17-py3-none-any.whl: theia/aws/serverless/lambda_.py <==
import pulumi

from pulumi_aws import lambda_
from pulumi.output import Output

from dataclasses import field
from typing import Optional, Literal, List, Mapping
from pydantic.dataclasses import dataclass, ConfigDict

from theia import ResourceOptions
from theia._registry import StackRegistry, GlobalTags
from theia.utils.errors import TheiaConfigurationError
from theia.definitions import THEIA_VERSION, LAMBDA_RUNTIMES


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class VpcConfig:
    security_group_ids: List[str | Output[str]]
    subnet_ids: List[str | Output[str]]
    vpc_id: Optional[str | Output[str]] = None


@dataclass(config=ConfigDict(arbitrary_types_allowed=True))
class FunctionSettings:
    architectures: List[Optional[Literal["x86_64", "arm64"]]] = field(default_factory=lambda: ["x86_64"])
    description: Optional[str] = None
    env_args: Optional[Mapping[str, str | Output[str]]] = None
    memory_size: Optional[int] = 128
    timeout: Optional[int] = 3
    alias_name: Optional[str] = None
    image_uri: Optional[str | Output[str]] = None
    s3_bucket: Optional[str | Output[str]] = None
    s3_key: Optional[str | Output[str]] = None
    s3_object_version: Optional[str | Output[str]] = None
    vpc_config: Optional[VpcConfig] = None
    api_permissions: Optional[List[str | Output[str]]] = None

    def __post_init__(self):
        if self.s3_bucket and not self.s3_key:
            raise TheiaConfigurationError("s3 bucket was configured as source but s3 key was not provided")


class Function:
    def __new__(
        cls,
        resource_name: str,
        role_arn: str,
        runtime: LAMBDA_RUNTIMES,
        code_path: Optional[str] = None,
        publish: Optional[bool] = False,
        handler: Optional[str] = False,
        settings: Optional[FunctionSettings] = FunctionSettings(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> lambda_.Function:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        if not code_path and not (settings.image_uri or settings.s3_bucket):
            raise TheiaConfigurationError(
                "Exactly one of code_path, FunctionSettings(image_uri) or FunctionSettings(s3_bucket) must be provided"
            )
        if settings.image_uri:
            package_type = "Image"
        else:
            package_type = "Zip"

        function_args = lambda_.FunctionArgs(
            role=role_arn,
            architectures=settings.architectures,
            code=pulumi.FileArchive(code_path),
            description=settings.description,
            environment=lambda_.FunctionEnvironmentArgs(variables=settings.env_args),
            package_type=package_type,
            handler=handler,
            image_uri=settings.image_uri,
            s3_bucket=settings.s3_bucket,
            s3_key=settings.s3_key,
            s3_object_version=settings.s3_object_version,
            runtime=runtime,
            publish=publish,
            memory_size=settings.memory_size,
            timeout=settings.timeout,
            vpc_config=lambda_.FunctionVpcConfigArgs(
                security_group_ids=settings.vpc_config.security_group_ids,
                subnet_ids=settings.vpc_config.subnet_ids,
                vpc_id=settings.vpc_config.vpc_id,
            ),
            tags=merged_tags,
        )

        function = lambda_.Function(resource_name, name=resource_name, args=function_args, opts=opts)

        if settings.alias_name:
            lambda_.Alias(resource_name=settings.alias_name, function_version=1, function_name=function.arn)

        if settings.api_permissions:
            for idx, api_execution_arn in enumerate(settings.api_permissions):
                lambda_.Permission(
                    resource_name=f"{resource_name}-permission-{idx}",
                    action="lambda:InvokeFunction",
                    function=function,
                    principal="apigateway.amazonaws.com",
                    source_arn=api_execution_arn,
                )

        pulumi.export(
            f"lambda---{resource_name}",
            {
                "id": function.id,
                "arn": function.arn,
                "invoke_arn": function.invoke_arn,
            },
        )

        return function

    @staticmethod
    def import_(stack: str, resource_name: str) -> lambda_.Function:
        stack_ref = StackRegistry.get(stack_name=stack)
        func = stack_ref.get_output(name=f"lambda---{resource_name}")
        return lambda_.Function.get(resource_name=resource_name, id=func["id"])
